| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.DocumentDB.Types.Tag
Description
Documentation
Metadata assigned to an Amazon DocumentDB resource consisting of a key-value pair.
See: newTag smart constructor.
Constructors
| Tag' | |
Fields
| |
Instances
| ToQuery Tag Source # | |
Defined in Amazonka.DocumentDB.Types.Tag Methods toQuery :: Tag -> QueryString # | |
| FromXML Tag Source # | |
| Generic Tag Source # | |
| Read Tag Source # | |
| Show Tag Source # | |
| NFData Tag Source # | |
Defined in Amazonka.DocumentDB.Types.Tag | |
| Eq Tag Source # | |
| Hashable Tag Source # | |
Defined in Amazonka.DocumentDB.Types.Tag | |
| type Rep Tag Source # | |
Defined in Amazonka.DocumentDB.Types.Tag type Rep Tag = D1 ('MetaData "Tag" "Amazonka.DocumentDB.Types.Tag" "amazonka-docdb-2.0-7OwFe1BulfiBtMsDpDrdzX" 'False) (C1 ('MetaCons "Tag'" 'PrefixI 'True) (S1 ('MetaSel ('Just "key") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 (Maybe Text)) :*: S1 ('MetaSel ('Just "value") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 (Maybe Text)))) | |
Create a value of Tag with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:key:Tag', tag_key - The required name of the tag. The string value can be from 1 to 128
Unicode characters in length and can't be prefixed with "aws:" or
"rds:". The string can contain only the set of Unicode letters,
digits, white space, '_', '.', '/', '=', '+', '-' (Java
regex: "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-]*)$").
$sel:value:Tag', tag_value - The optional value of the tag. The string value can be from 1 to 256
Unicode characters in length and can't be prefixed with "aws:" or
"rds:". The string can contain only the set of Unicode letters,
digits, white space, '_', '.', '/', '=', '+', '-' (Java
regex: "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-]*)$").
tag_key :: Lens' Tag (Maybe Text) Source #
The required name of the tag. The string value can be from 1 to 128
Unicode characters in length and can't be prefixed with "aws:" or
"rds:". The string can contain only the set of Unicode letters,
digits, white space, '_', '.', '/', '=', '+', '-' (Java
regex: "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-]*)$").
tag_value :: Lens' Tag (Maybe Text) Source #
The optional value of the tag. The string value can be from 1 to 256
Unicode characters in length and can't be prefixed with "aws:" or
"rds:". The string can contain only the set of Unicode letters,
digits, white space, '_', '.', '/', '=', '+', '-' (Java
regex: "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-]*)$").